@@ -218,6 +218,7 @@ class anim_text:
         self.obj = bpy.data.objects[name+'_text']
 
         self.obj.parent = parent
+        self.name = name
 
 
     def animate(self, data, label, fix_place, if_str):
@@ -225,7 +226,7 @@ class anim_text:
 
         if not(if_str):
             def update(self):
-                text = self.obj
+                text = bpy.data.objects[self.name+'_text']
                 cur_frame = bpy.context.scene.frame_current
                 
                 if np.any(cur_frame == anim.frames):
@@ -234,7 +235,7 @@ class anim_text:
                     
         else:
             def update(self):
-                text = self.obj
+                text = bpy.data.objects[self.name+'_text']
                 cur_frame = bpy.context.scene.frame_current
                 
                 if np.any(cur_frame == anim.frames):
